---
sidebar_position: 9
---

# Changelog

## 0.1.31

- Added streaming support for Groq, Cerebras, Anthropic and Sambanova.

## 0.1.30

- Fixed some issues with the structured output response example.

## 0.1.28

- Bug fix: reasoning to Fireworks structured output.
- Added reasoning to Fireworks structured output.

## 0.1.27

- Added structured completion skills for Fireworks AI
- Added Completion skills for Fireworks AI.
- Added Combination skill for Groq and Fireworks AI.
- Add completion streaming.
- Added strcutured output streaming for Fireworks AI.

## 0.1.23

- Added conversation support for Deepseek, Togehter AI, Fireworks AI, Gemini, Groq, Cerebras and Sambanova.
- Added Change Log


## Notes

The changelog format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html). 